from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, Int

Efn2_Smp_V0_1_0 = CommandToolBuilder(tool="efn2_smp", base_command=["efn2-smp"], inputs=[ToolInput(tag="in_dna", input_type=Boolean(optional=True), prefix="--DNA", doc=InputDocumentation(doc="Specify that the sequence is DNA, and DNA parameters are to be used.\nDefault is to use RNA parameters.")), ToolInput(tag="in_ne", input_type=Boolean(optional=True), prefix="--ne", doc=InputDocumentation(doc="Do not calculate experimental uncertainties")), ToolInput(tag="in_print", input_type=File(optional=True), prefix="--print", doc=InputDocumentation(doc="Print the simple list file to standard output. This won't override default\nbehavior of writing to a file. Thermodynamic files (if written) are not\npiped. This option implies --quiet.")), ToolInput(tag="in_quiet", input_type=File(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Suppress unnecessary output. This option is implied when the output file is\n'-' (STDOUT) or when the --print flag is present.")), ToolInput(tag="in_simple", input_type=Boolean(optional=True), prefix="--simple", doc=InputDocumentation(doc="Specify the simple energy function for multibranch loops, used by the\ndynamic programming algorithms (Fold, partition, stochastic, AllSub, etc.),\nshould be used. If this is not specified, an more sophisticated energy\nfunction is used, and the energies might not match those estimated for\nstructures during structure prediction.")), ToolInput(tag="in_write_details", input_type=Boolean(optional=True), prefix="--writedetails", doc=InputDocumentation(doc="Write a thermodynamic details file. The thermodynamic details file replaces\nthe list file that is outputted by default.")), ToolInput(tag="in_alphabet", input_type=Boolean(optional=True), prefix="--alphabet", doc=InputDocumentation(doc="Specify the name of a folding alphabet and associated nearest neighbor\nparameters. The alphabet is the prefix for the thermodynamic parameter\nfiles, e.g. 'rna' for RNA parameters or 'dna' for DNA parameters or a\ncustom extended/modified alphabet. The thermodynamic parameters need to\nreside in the at the location indicated by environment variable DATAPATH.\nThe default is 'rna' (i.e. use RNA parameters). This option overrides the\n--DNA flag.")), ToolInput(tag="in_count", input_type=Boolean(optional=True), prefix="--count", doc=InputDocumentation(doc="Specify a file where parameter usage counts will be exported")), ToolInput(tag="in_shape", input_type=Boolean(optional=True), prefix="--SHAPE", doc=InputDocumentation(doc="Specify a SHAPE constraints file to be applied. These constraints are\npseudoenergy constraints.\nDefault is to have no constraints applied.")), ToolInput(tag="in_shape_intercept", input_type=Boolean(optional=True), prefix="--SHAPEintercept", doc=InputDocumentation(doc="Specify an intercept used with SHAPE constraints.\nDefault is -0.6 kcal/mol.")), ToolInput(tag="in_shape_slope", input_type=Boolean(optional=True), prefix="--SHAPEslope", doc=InputDocumentation(doc="Specify a slope used with SHAPE constraints.\nDefault is 1.8 kcal/mol.")), ToolInput(tag="in_temperature", input_type=Boolean(optional=True), prefix="--temperature", doc=InputDocumentation(doc="Specify the temperature at which calculation takes place in Kelvin.\nDefault is 310.15 K, which is 37 degrees C.\n")), ToolInput(tag="in_efn_two", input_type=Int(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_ct_file", input_type=File(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_output_file", input_type=File(), position=2, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_print", output_type=File(optional=True), selector=InputSelector(input_to_select="in_print", type_hint=File()), doc=OutputDocumentation(doc="Print the simple list file to standard output. This won't override default\nbehavior of writing to a file. Thermodynamic files (if written) are not\npiped. This option implies --quiet.")), ToolOutput(tag="out_quiet", output_type=File(optional=True), selector=InputSelector(input_to_select="in_quiet", type_hint=File()), doc=OutputDocumentation(doc="Suppress unnecessary output. This option is implied when the output file is\n'-' (STDOUT) or when the --print flag is present.")), ToolOutput(tag="out_output_file", output_type=File(), selector=InputSelector(input_to_select="in_output_file", type_hint=File()), doc=OutputDocumentation(doc=""))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Efn2_Smp_V0_1_0().translate("wdl", allow_empty_container=True)

